<?php 
// $Id: user_activity.rules.inc,v 1.1 2008/11/09 13:05:43 stalski Exp $ 
// by Jochen Stals - ONE-agency - www.one-agency.be


/**
* Implementation of hook_rules_data_type_info()
*/
function user_activity_rules_data_type_info() {
  return array(
    'message' => array(
      'label' => t('Logged message'),
      'class' => 'rules_data_type_message',
      'identifiable' => FALSE,
    ),
  );
}

/**
* Rules relation_message data type
*/
class rules_data_type_message extends rules_data_type {
}


# ACTIONS

/**
 * Implementation of hook_rules_action_info().
 * @ingroup rules
 */
function user_activity_rules_action_info() {
  $info = array(
    'rules_user_activity_action' => array(
      'label' => t('Logs relational user activity'),
      'eval input' => array(
        'uid_param',
        'uid_target_param',
        'nid_target_param',
        'message_param',
        'variables_param'
      ),
      'help' => 'Create a relation between users by logging their activities',
      'module' => 'User activity',
    ),
  );
  return $info;
}

/**
 * Action drupal message configuration form.
 */
function rules_user_activity_action_form($settings, &$form) {
  $settings += array(
    'uid_param' => '', 
    'uid_target_param' => '', 
    'nid_target_param' => '', 
    'message_param' => '', 
    'variables_param' => ''
  );
  $form['settings']['uid_param'] = array(
    '#type' => 'textfield',
    '#size' => '15',
    '#maxsize' => '25',
    '#title' => t('User'),
    '#default_value' => $settings['uid_param'],
    '#description' => t('The user doing the activity'),
  );
  $form['settings']['uid_target_param'] = array(
    '#type' => 'textfield',
    '#size' => '15',
    '#maxsize' => '25',
    '#title' => t('User target'),
    '#default_value' => $settings['uid_target_param'],
    '#description' => t('The user target of the activity'),
  );
  $form['settings']['nid_target_param'] = array(
    '#type' => 'textfield',
    '#size' => '15',
    '#maxsize' => '25',
    '#title' => t('Node target'),
    '#default_value' => $settings['nid_target_param'],
    '#description' => t('The node target of the activity'),
  );
  $form['settings']['message_param'] = array(
    '#type' => 'textfield',
    '#size' => '250',
    '#maxsize' => '250',
    '#title' => t('The message'),
    '#default_value' => $settings['message_param'],
    '#description' => t('The message'),
  );
  $form['settings']['variables_param'] = array(
    '#type' => 'textarea',
    '#title' => t('The variables area.'),
    '#default_value' => $settings['variables_param'],
    '#description' => t('The variables, leave empty or use with care! <br /> Extra modular stuff goes here with the synthax:<br /><b>var1:value1;var2:value2;va</b> ...'),
  );
}

/**
 * Action Implementation: Log an activity
 *
 * @param array $settings
 * @param array form
 * @param array with two arrays (set_info and variables)
 * @ToDo  figure out what params mean / can do
 */
function rules_user_activity_action($settings, $form=array(), $event_info=array()){
  //dsm(func_get_args());
  $data = array();
	$data['uid'] = $settings['uid_param'];
  $data['uid_target'] = $settings['uid_target_param'];
  $data['nid_target'] = $settings['nid_target_param'];
  $data['message'] = $settings['message_param'];
  $data['variables'] = $settings['variables_param'];
  $event = '';
  if(isset($event_info['set_info']['label']) ){
  	$data['event'] = $event_info['set_info']['label'];
  }
  user_activity_log($data); 
}


# Conditions

/**
 * Implentation of hook_rules_conditions_info().
 */
function user_activity_rules_condition_info() {
  // example code here
}


# TOKENS

/**
 * Implementation of hook_token_list().
 */
function user_activity_token_list($type = 'all') {
  if ($type == 'logged__message') {
    $tokens['message']['string-raw'] = t("The raw message");
  }
  if ($type == 'boolean') {
    $tokens['boolean']['1-or-0'] = t("1 for true, 0 for false");
  }
  if ($type == 'node') {
    $tokens['node']['title-link'] = t("The node's title with a link to it");
  }
  if ($type == 'user') {
    $tokens['node']['user-name-url'] = t("The user's name with a link to it");
  }
  return $tokens;
}

/**
 * Implementation of hook_token_values().
 */
function user_activity_token_values($type, $object = NULL, $options = array()) {
  $values = array();
  switch ($type) {
    case 'message':
      $values['raw'] = $object;
    break;
    case 'boolean':
      $values['1-or-0'] = $object ?  '1' : '0' ;
      break;
    case 'node':
      $values['title-link'] = l($object->title,'node/'.$object->nid);
      break;
    case 'user':
      $values['user-name-url'] = l($object->name,'user/'.$object->uid);
      break;
  }
  return $values;
}